from qm.pb.frontend_pb2 import SimulationRequest
from qm.simulate.interface import SimulatorInterface
from qm.grpc.quantum_simulator.v1 import PhysicalConfig


class QuantumSimulatorInterface(SimulatorInterface):
    def __init__(self, physical_config: PhysicalConfig) -> None:
        super().__init__()
        self._physical_config = physical_config

    def update_simulate_request(self, request: SimulationRequest):
        super().update_simulate_request(request)
        request.simulate.simulationInterface.quantum_simulator.SetInParent()

        request.simulate.simulationInterface.quantum_simulator.physical_config = bytes(
            self._physical_config
        )



from qm.pb.inc_qua_pb2 import QuaProgram

from qm._loc import _get_loc


class StatementsCollection(object):
    def __init__(self, body):
        super(StatementsCollection, self).__init__()
        self._body = body

    def play(
        self,
        pulse,
        element,
        duration=None,
        condition=None,
        target="",
        chirp=None,
        truncate=None,
    ):
        """
        Play a pulse to a quantum element as per the OPX config
        :param pulse: A tuple (pulse, amp). pulse is string of pulse name, amp is a 4 matrix
        :param element:
        :param duration:
        :param condition:
        :param target:
        :return:
        """

        amp = None
        if type(pulse) is tuple:
            pulse, amp = pulse

        loc = _get_loc()
        statement = self._body.statements.add()
        statement.play.SetInParent()
        statement.play.loc = loc
        if isinstance(pulse, QuaProgram.RampPulse):
            statement.play.rampPulse.SetInParent()
            statement.play.rampPulse.CopyFrom(pulse)
        else:
            statement.play.namedPulse.SetInParent()
            statement.play.namedPulse.name = pulse
            statement.play.pulse.name = pulse
        statement.play.qe.name = element
        statement.play.targetInput = target
        if duration is not None:
            statement.play.duration.CopyFrom(duration)
        if condition is not None:
            statement.play.condition.CopyFrom(condition)
        if chirp is not None:
            statement.play.chirp.CopyFrom(chirp)
            statement.play.chirp.loc = loc
        if amp is not None:
            statement.play.amp.SetInParent()
            statement.play.amp.loc = loc
            statement.play.amp.v0.CopyFrom(amp[0])
            for i in range(1, 4, 1):
                if amp[i] is not None:
                    getattr(statement.play.amp, "v" + str(i)).CopyFrom(amp[i])
        if truncate is not None:
            statement.play.truncate.CopyFrom(truncate)

    def pause(self, *elements):
        """
        Pause the execution of the given quantum elements
        :param elements:
        :return:
        """
        statement = self._body.statements.add()
        statement.pause.SetInParent()
        statement.pause.loc = _get_loc()
        for element in elements:
            element_ref = statement.pause.qe.add()
            element_ref.name = element

    def update_frequency(self, element, new_frequency, units, keep_phase):
        """
        Updates the frequency of a given element
        :param element: The element to set the frequency to
        :param new_frequency: The new frequency value to set
        :return:
        """
        statement = self._body.statements.add()
        statement.updateFrequency.SetInParent()
        statement.updateFrequency.loc = _get_loc()
        statement.updateFrequency.qe.name = element
        if units == "Hz":
            statement.updateFrequency.units = QuaProgram.UpdateFrequencyStatement.Hz
        elif units == "mHz":
            statement.updateFrequency.units = QuaProgram.UpdateFrequencyStatement.mHz
        elif units == "uHz":
            statement.updateFrequency.units = QuaProgram.UpdateFrequencyStatement.uHz
        elif units == "nHz":
            statement.updateFrequency.units = QuaProgram.UpdateFrequencyStatement.nHz
        elif units == "pHz":
            statement.updateFrequency.units = QuaProgram.UpdateFrequencyStatement.pHz
        else:
            raise RuntimeError(f'unknown units "{units}"')
        statement.updateFrequency.keepPhase = keep_phase
        statement.updateFrequency.value.CopyFrom(new_frequency)

    def update_correction(self, element, c00, c01, c10, c11):
        """
        Updates the correction of a given element
        :param element: The element to set the correction to
        :param c00: The top left matrix element
        :param c01: The top right matrix element
        :param c10: The bottom left matrix element
        :param c11: The bottom right matrix element
        """
        statement = self._body.statements.add()
        statement.updateCorrection.SetInParent()
        statement.updateCorrection.qe.name = element
        statement.updateCorrection.loc = _get_loc()
        statement.updateCorrection.correction.SetInParent()
        statement.updateCorrection.correction.c0.CopyFrom(c00)
        statement.updateCorrection.correction.c1.CopyFrom(c01)
        statement.updateCorrection.correction.c2.CopyFrom(c10)
        statement.updateCorrection.correction.c3.CopyFrom(c11)

    def set_dc_offset(self, element, element_input, offset):
        """
        Update the DC offset of an element's input
        :param element: The element to update its DC offset
        :param element_input: desired input of the element, can be 'single' for a 'singleInput' element
            or 'I' or 'Q' for a 'mixInputs' element
        :param offset: Desired dc offset for single
        """
        statement = self._body.statements.add()
        statement.setDcOffset.SetInParent()
        statement.setDcOffset.loc = _get_loc()
        statement.setDcOffset.qe.name = element
        statement.setDcOffset.qeInputReference = element_input
        statement.setDcOffset.offset.CopyFrom(offset)

    def advance_input_stream(self, input_stream):
        """
        advance an input stream pointer to be sent to the QUA program
        :param input_stream: The input stream to advance
        """
        statement = self._body.statements.add()
        statement.advanceInputStream.SetInParent()
        statement.advanceInputStream.loc = _get_loc()
        if isinstance(input_stream, QuaProgram.ArrayVarRefExpression):
            statement.advanceInputStream.streamArray.CopyFrom(input_stream)
        elif (
            isinstance(input_stream, QuaProgram.AnyScalarExpression)
            and input_stream.WhichOneof("expression_oneof") == "variable"
        ):
            statement.advanceInputStream.streamVariable.CopyFrom(input_stream.variable)
        else:
            raise RuntimeError("unsupported type for advance input stream")

    def align(self, *elements):
        """
        Align the given elements
        :param elements:
        :return:
        """
        statement = self._body.statements.add()
        statement.align.SetInParent()
        statement.align.loc = _get_loc()
        for element in elements:
            element_ref = statement.align.qe.add()
            element_ref.name = element

    def reset_phase(self, element):
        """
        TODO: document
        :param element:
        :return:
        """
        statement = self._body.statements.add()
        statement.resetPhase.SetInParent()
        statement.resetPhase.qe.SetInParent()
        statement.resetPhase.qe.name = element

    def wait(self, duration, *elements):
        """
        Waits for the given duration on all provided elements
        :param duration:
        :param elements:
        :return:
        """
        statement = self._body.statements.add()
        statement.wait.SetInParent()
        statement.wait.loc = _get_loc()
        statement.wait.time.CopyFrom(duration)
        for element in elements:
            element_ref = statement.wait.qe.add()
            element_ref.name = element

    def wait_for_trigger(self, pulse_to_play, trigger_element, *elements):
        statement = self._body.statements.add()
        statement.waitForTrigger.SetInParent()
        statement.waitForTrigger.loc = _get_loc()
        if pulse_to_play is not None:
            statement.waitForTrigger.pulseToPlay.name = pulse_to_play
        if trigger_element is not None:
            statement.waitForTrigger.elementOutput.SetInParent()
            if type(trigger_element) == tuple:
                statement.waitForTrigger.elementOutput.element = trigger_element[0]
                statement.waitForTrigger.elementOutput.output = trigger_element[1]
            else:
                statement.waitForTrigger.elementOutput.element = trigger_element
        else:
            statement.waitForTrigger.globalTrigger.SetInParent()
        for element in elements:
            element_ref = statement.waitForTrigger.qe.add()
            element_ref.name = element

    def save(self, source, result):
        statement = self._body.statements.add()
        statement.save.SetInParent()
        statement.save.loc = _get_loc()
        statement.save.source.CopyFrom(source)
        statement.save.tag = result._get_var_name()

    def z_rotation(self, angle, *elements):
        for element in elements:
            statement = self._body.statements.add()
            statement.zRotation.SetInParent()
            statement.zRotation.loc = _get_loc()
            statement.zRotation.value.CopyFrom(angle)
            statement.zRotation.qe.name = element

    def reset_frame(self, *elements):
        for element in elements:
            statement = self._body.statements.add()
            statement.resetFrame.SetInParent()
            statement.resetFrame.loc = _get_loc()
            statement.resetFrame.qe.name = element

    def ramp_to_zero(self, element, duration):
        statement = self._body.statements.add()
        statement.rampToZero.SetInParent()
        statement.rampToZero.qe.SetInParent()
        statement.rampToZero.qe.name = element
        if duration is not None:
            statement.rampToZero.duration.SetInParent()
            statement.rampToZero.duration.value = duration

    def measure(self, pulse, element, stream=None, *processes):
        """
        Measure an element using the given pulse, process the result with the integration weights and
        store the results to the provided variables
        :param pulse:
        :param element:
        :param stream:
        :type stream: _ResultSource
        :param processes: an iterable of analog processes
        :return:
        """
        amp = None
        if type(pulse) is tuple:
            pulse, amp = pulse

        loc = _get_loc()
        statement = self._body.statements.add()
        statement.measure.SetInParent()
        statement.measure.loc = loc
        statement.measure.pulse.name = pulse
        statement.measure.qe.name = element
        if stream is not None:
            statement.measure.streamAs = stream._get_var_name()

        for analog_process in processes:
            added_process = statement.measure.measureProcesses.add()
            added_process.CopyFrom(analog_process)

        if amp is not None:
            statement.measure.amp.SetInParent()
            statement.measure.amp.loc = loc
            statement.measure.amp.v0.CopyFrom(amp[0])
            for i in range(1, 4, 1):
                if amp[i] is not None:
                    getattr(statement.measure.amp, "v" + str(i)).CopyFrom(amp[i])

    def if_block(self, condition, unsafe=False):
        statement = self._body.statements.add()
        ifstatement = getattr(statement, "if")
        ifstatement.SetInParent()
        ifstatement.loc = _get_loc()
        ifstatement.condition.CopyFrom(condition)
        ifstatement.unsafe = unsafe
        ifstatement.body.SetInParent()
        return StatementsCollection(ifstatement.body)

    def for_each(self, iterators):
        statement = self._body.statements.add()
        forEach = statement.forEach
        forEach.SetInParent()
        forEach.loc = _get_loc()
        for it in iterators:
            pb_it = forEach.iterator.add()
            pb_it.variable.CopyFrom(it[0])
            pb_it.array.CopyFrom(it[1])
        forEach.body.SetInParent()
        return StatementsCollection(forEach.body)

    def get_last_statement(self):
        statements = self._body.statements
        l = len(statements)
        if l == 0:
            return None
        return statements[l - 1]

    def for_block(self):
        statement = self._body.statements.add()
        forstatement = getattr(statement, "for")
        forstatement.SetInParent()
        forstatement.loc = _get_loc()
        return forstatement

    def qrun_block(self):
        statement = self._body.statements.add()
        qrun_statement = statement.qrun
        qrun_statement.SetInParent()
        qrun_statement.loc = _get_loc()
        return qrun_statement

    def assign(self, target, expression):
        """
        Assign a value calculated by :expression into :target
        :param target: The name of the variable to assign to
        :param expression: The expression to calculate
        :return:
        """
        statement = self._body.statements.add()
        statement.assign.SetInParent()
        statement.assign.loc = _get_loc()
        statement.assign.target.CopyFrom(target)
        statement.assign.expression.CopyFrom(expression)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qm/pb/inc_qm_api.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.pb import inc_qua_config_pb2 as qm_dot_pb_dot_inc__qua__config__pb2
from qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='qm/pb/inc_qm_api.proto',
  package='qm.grpc.qm_api',
  syntax='proto3',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16qm/pb/inc_qm_api.proto\x12\x0eqm.grpc.qm_api\x1a\x1aqm/pb/inc_qua_config.proto\x1a\x1cqm/pb/general_messages.proto\x1a\x1cgoogle/protobuf/struct.proto\"\x9c\x11\n\x10HighQmApiRequest\x12,\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x18.qm.grpc.qm_api.QmConfigB\x02\x18\x01\x12\x37\n\x0cstrongConfig\x18\x02 \x01(\x0b\x32\x1d.qm.grpc.qua_config.QuaConfigB\x02\x18\x01\x12\x18\n\x10quantumMachineId\x18\x03 \x01(\t\x12G\n\rsetCorrection\x18\x33 \x01(\x0b\x32..qm.grpc.qm_api.HighQmApiRequest.SetCorrectionH\x00\x12\x45\n\x0csetFrequency\x18\x34 \x01(\x0b\x32-.qm.grpc.qm_api.HighQmApiRequest.SetFrequencyH\x00\x12G\n\x0bsetDcOffset\x18\x35 \x01(\x0b\x32,.qm.grpc.qm_api.HighQmApiRequest.SetDcOffsetB\x02\x18\x01H\x00\x12K\n\x0fsetDigitalRoute\x18\x36 \x01(\x0b\x32\x30.qm.grpc.qm_api.HighQmApiRequest.SetDigitalRouteH\x00\x12\x43\n\x0bsetIOValues\x18\x37 \x01(\x0b\x32,.qm.grpc.qm_api.HighQmApiRequest.SetIOValuesH\x00\x12M\n\x10setInputDcOffset\x18\x38 \x01(\x0b\x32\x31.qm.grpc.qm_api.HighQmApiRequest.SetInputDcOffsetH\x00\x12O\n\x11setOutputDcOffset\x18\x39 \x01(\x0b\x32\x32.qm.grpc.qm_api.HighQmApiRequest.SetOutputDcOffsetH\x00\x12S\n\x13setOutputFilterTaps\x18: \x01(\x0b\x32\x34.qm.grpc.qm_api.HighQmApiRequest.SetOutputFilterTapsH\x00\x1a\xab\x01\n\rSetCorrection\x12*\n\ncorrection\x18\x01 \x01(\x0b\x32\x16.qm.grpc.qm_api.Matrix\x12\x0c\n\x02qe\x18\n \x01(\tH\x00\x12H\n\x05mixer\x18\x0b \x01(\x0b\x32\x37.qm.grpc.qm_api.HighQmApiRequest.SetCorrectionMixerInfoH\x00\x42\x16\n\x14oneof_set_correction\x1av\n\x16SetCorrectionMixerInfo\x12\r\n\x05mixer\x18\x01 \x01(\t\x12\x1d\n\x15intermediateFrequency\x18\x02 \x01(\x04\x12\x13\n\x0bloFrequency\x18\x03 \x01(\x04\x12\x19\n\x11\x66requencyNegative\x18\x04 \x01(\x08\x1a\x42\n\x0cSetFrequency\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0c\n\x02qe\x18\n \x01(\tH\x00\x42\x15\n\x13oneof_set_frequency\x1aj\n\x0bSetDcOffset\x12\t\n\x01I\x18\x01 \x01(\x01\x12\t\n\x01Q\x18\x02 \x01(\x01\x12\x35\n\x02qe\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x42\x0e\n\x0coneof_set_dc\x1ap\n\x11SetOutputDcOffset\x12\t\n\x01I\x18\x01 \x01(\x01\x12\t\n\x01Q\x18\x02 \x01(\x01\x12\x35\n\x02qe\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x42\x0e\n\x0coneof_set_dc\x1a\xae\x01\n\x13SetOutputFilterTaps\x12G\n\x06\x66ilter\x18\x01 \x01(\x0b\x32\x37.qm.grpc.qm_api.HighQmApiRequest.AnalogOutputPortFilter\x12\x35\n\x02qe\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x42\x17\n\x15oneof_set_filter_Taps\x1a?\n\x16\x41nalogOutputPortFilter\x12\x13\n\x0b\x66\x65\x65\x64\x66orward\x18\x01 \x03(\x01\x12\x10\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x02 \x03(\x01\x1ai\n\x10SetInputDcOffset\x12\x0e\n\x06offset\x18\x01 \x01(\x01\x12\x35\n\x02qe\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x42\x0e\n\x0coneof_set_dc\x1a\xd3\x01\n\x0fSetDigitalRoute\x12\r\n\x05value\x18\x01 \x01(\r\x12\x38\n\x05\x64\x65lay\x18\n \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x12\x39\n\x06\x62uffer\x18\x0b \x01(\x0b\x32\'.qm.grpc.qm_api.HighQmApiRequest.QePortH\x00\x12\r\n\x03tof\x18\x0c \x01(\tH\x00\x12\x12\n\x08smearing\x18\r \x01(\tH\x00\x42\x19\n\x17oneof_set_digital_route\x1a|\n\x0bSetIOValues\x12\r\n\x03\x61ll\x18\x01 \x01(\x08H\x00\x12G\n\x0eioValueSetData\x18\x33 \x03(\x0b\x32/.qm.grpc.qm_api.HighQmApiRequest.IOValueSetDataB\x0f\n\roneof_setTypeJ\x04\x08\x02\x10\x33\x1a\"\n\x06QePort\x12\n\n\x02qe\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\t\x1aw\n\x0eIOValueSetData\x12\x11\n\tio_number\x18\x01 \x01(\x05\x12\x12\n\x08intValue\x18\x02 \x01(\x05H\x00\x12\x15\n\x0b\x64oubleValue\x18\x03 \x01(\x01H\x00\x12\x16\n\x0c\x62ooleanValue\x18\x04 \x01(\x08H\x00\x42\x0f\n\roneof_IO_typeB\x0b\n\tapi_oneofJ\x04\x08\x04\x10\x33\"W\n\x11HighQmApiResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x36\n\x06\x65rrors\x18\x02 \x03(\x0b\x32&.qm.grpc.general_messages.ErrorMessage\"B\n\x08QmConfig\x12\x0f\n\x07version\x18\x01 \x01(\r\x12%\n\x04root\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"<\n\x06Matrix\x12\x0b\n\x03v00\x18\x01 \x01(\x01\x12\x0b\n\x03v01\x18\x02 \x01(\x01\x12\x0b\n\x03v10\x18\x03 \x01(\x01\x12\x0b\n\x03v11\x18\x04 \x01(\x01\"3\n\rPortReference\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\rb\x06proto3'
  ,
  dependencies=[qm_dot_pb_dot_inc__qua__config__pb2.DESCRIPTOR,qm_dot_pb_dot_general__messages__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,])




_HIGHQMAPIREQUEST_SETCORRECTION = _descriptor.Descriptor(
  name='SetCorrection',
  full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrection.correction', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrection.qe', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mixer', full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrection.mixer', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_set_correction', full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrection.oneof_set_correction',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=889,
  serialized_end=1060,
)

_HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO = _descriptor.Descriptor(
  name='SetCorrectionMixerInfo',
  full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrectionMixerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mixer', full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrectionMixerInfo.mixer', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intermediateFrequency', full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrectionMixerInfo.intermediateFrequency', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='loFrequency', full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrectionMixerInfo.loFrequency', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='frequencyNegative', full_name='qm.grpc.qm_api.HighQmApiRequest.SetCorrectionMixerInfo.frequencyNegative', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1062,
  serialized_end=1180,
)

_HIGHQMAPIREQUEST_SETFREQUENCY = _descriptor.Descriptor(
  name='SetFrequency',
  full_name='qm.grpc.qm_api.HighQmApiRequest.SetFrequency',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qm_api.HighQmApiRequest.SetFrequency.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qm_api.HighQmApiRequest.SetFrequency.qe', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_set_frequency', full_name='qm.grpc.qm_api.HighQmApiRequest.SetFrequency.oneof_set_frequency',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1182,
  serialized_end=1248,
)

_HIGHQMAPIREQUEST_SETDCOFFSET = _descriptor.Descriptor(
  name='SetDcOffset',
  full_name='qm.grpc.qm_api.HighQmApiRequest.SetDcOffset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='I', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDcOffset.I', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Q', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDcOffset.Q', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDcOffset.qe', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_set_dc', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDcOffset.oneof_set_dc',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1250,
  serialized_end=1356,
)

_HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET = _descriptor.Descriptor(
  name='SetOutputDcOffset',
  full_name='qm.grpc.qm_api.HighQmApiRequest.SetOutputDcOffset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='I', full_name='qm.grpc.qm_api.HighQmApiRequest.SetOutputDcOffset.I', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='Q', full_name='qm.grpc.qm_api.HighQmApiRequest.SetOutputDcOffset.Q', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qm_api.HighQmApiRequest.SetOutputDcOffset.qe', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_set_dc', full_name='qm.grpc.qm_api.HighQmApiRequest.SetOutputDcOffset.oneof_set_dc',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1358,
  serialized_end=1470,
)

_HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS = _descriptor.Descriptor(
  name='SetOutputFilterTaps',
  full_name='qm.grpc.qm_api.HighQmApiRequest.SetOutputFilterTaps',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='filter', full_name='qm.grpc.qm_api.HighQmApiRequest.SetOutputFilterTaps.filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qm_api.HighQmApiRequest.SetOutputFilterTaps.qe', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_set_filter_Taps', full_name='qm.grpc.qm_api.HighQmApiRequest.SetOutputFilterTaps.oneof_set_filter_Taps',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1473,
  serialized_end=1647,
)

_HIGHQMAPIREQUEST_ANALOGOUTPUTPORTFILTER = _descriptor.Descriptor(
  name='AnalogOutputPortFilter',
  full_name='qm.grpc.qm_api.HighQmApiRequest.AnalogOutputPortFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='feedforward', full_name='qm.grpc.qm_api.HighQmApiRequest.AnalogOutputPortFilter.feedforward', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='feedback', full_name='qm.grpc.qm_api.HighQmApiRequest.AnalogOutputPortFilter.feedback', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1649,
  serialized_end=1712,
)

_HIGHQMAPIREQUEST_SETINPUTDCOFFSET = _descriptor.Descriptor(
  name='SetInputDcOffset',
  full_name='qm.grpc.qm_api.HighQmApiRequest.SetInputDcOffset',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='qm.grpc.qm_api.HighQmApiRequest.SetInputDcOffset.offset', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qm_api.HighQmApiRequest.SetInputDcOffset.qe', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_set_dc', full_name='qm.grpc.qm_api.HighQmApiRequest.SetInputDcOffset.oneof_set_dc',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1714,
  serialized_end=1819,
)

_HIGHQMAPIREQUEST_SETDIGITALROUTE = _descriptor.Descriptor(
  name='SetDigitalRoute',
  full_name='qm.grpc.qm_api.HighQmApiRequest.SetDigitalRoute',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDigitalRoute.value', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='delay', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDigitalRoute.delay', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDigitalRoute.buffer', index=2,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tof', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDigitalRoute.tof', index=3,
      number=12, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='smearing', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDigitalRoute.smearing', index=4,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_set_digital_route', full_name='qm.grpc.qm_api.HighQmApiRequest.SetDigitalRoute.oneof_set_digital_route',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1822,
  serialized_end=2033,
)

_HIGHQMAPIREQUEST_SETIOVALUES = _descriptor.Descriptor(
  name='SetIOValues',
  full_name='qm.grpc.qm_api.HighQmApiRequest.SetIOValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='all', full_name='qm.grpc.qm_api.HighQmApiRequest.SetIOValues.all', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ioValueSetData', full_name='qm.grpc.qm_api.HighQmApiRequest.SetIOValues.ioValueSetData', index=1,
      number=51, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_setType', full_name='qm.grpc.qm_api.HighQmApiRequest.SetIOValues.oneof_setType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2035,
  serialized_end=2159,
)

_HIGHQMAPIREQUEST_QEPORT = _descriptor.Descriptor(
  name='QePort',
  full_name='qm.grpc.qm_api.HighQmApiRequest.QePort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='qe', full_name='qm.grpc.qm_api.HighQmApiRequest.QePort.qe', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='qm.grpc.qm_api.HighQmApiRequest.QePort.port', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2161,
  serialized_end=2195,
)

_HIGHQMAPIREQUEST_IOVALUESETDATA = _descriptor.Descriptor(
  name='IOValueSetData',
  full_name='qm.grpc.qm_api.HighQmApiRequest.IOValueSetData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='io_number', full_name='qm.grpc.qm_api.HighQmApiRequest.IOValueSetData.io_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='intValue', full_name='qm.grpc.qm_api.HighQmApiRequest.IOValueSetData.intValue', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='doubleValue', full_name='qm.grpc.qm_api.HighQmApiRequest.IOValueSetData.doubleValue', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='booleanValue', full_name='qm.grpc.qm_api.HighQmApiRequest.IOValueSetData.booleanValue', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='oneof_IO_type', full_name='qm.grpc.qm_api.HighQmApiRequest.IOValueSetData.oneof_IO_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2197,
  serialized_end=2316,
)

_HIGHQMAPIREQUEST = _descriptor.Descriptor(
  name='HighQmApiRequest',
  full_name='qm.grpc.qm_api.HighQmApiRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='qm.grpc.qm_api.HighQmApiRequest.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='strongConfig', full_name='qm.grpc.qm_api.HighQmApiRequest.strongConfig', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='quantumMachineId', full_name='qm.grpc.qm_api.HighQmApiRequest.quantumMachineId', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setCorrection', full_name='qm.grpc.qm_api.HighQmApiRequest.setCorrection', index=3,
      number=51, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setFrequency', full_name='qm.grpc.qm_api.HighQmApiRequest.setFrequency', index=4,
      number=52, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setDcOffset', full_name='qm.grpc.qm_api.HighQmApiRequest.setDcOffset', index=5,
      number=53, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\030\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setDigitalRoute', full_name='qm.grpc.qm_api.HighQmApiRequest.setDigitalRoute', index=6,
      number=54, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setIOValues', full_name='qm.grpc.qm_api.HighQmApiRequest.setIOValues', index=7,
      number=55, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setInputDcOffset', full_name='qm.grpc.qm_api.HighQmApiRequest.setInputDcOffset', index=8,
      number=56, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setOutputDcOffset', full_name='qm.grpc.qm_api.HighQmApiRequest.setOutputDcOffset', index=9,
      number=57, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setOutputFilterTaps', full_name='qm.grpc.qm_api.HighQmApiRequest.setOutputFilterTaps', index=10,
      number=58, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HIGHQMAPIREQUEST_SETCORRECTION, _HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO, _HIGHQMAPIREQUEST_SETFREQUENCY, _HIGHQMAPIREQUEST_SETDCOFFSET, _HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET, _HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS, _HIGHQMAPIREQUEST_ANALOGOUTPUTPORTFILTER, _HIGHQMAPIREQUEST_SETINPUTDCOFFSET, _HIGHQMAPIREQUEST_SETDIGITALROUTE, _HIGHQMAPIREQUEST_SETIOVALUES, _HIGHQMAPIREQUEST_QEPORT, _HIGHQMAPIREQUEST_IOVALUESETDATA, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='api_oneof', full_name='qm.grpc.qm_api.HighQmApiRequest.api_oneof',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=131,
  serialized_end=2335,
)


_HIGHQMAPIRESPONSE = _descriptor.Descriptor(
  name='HighQmApiResponse',
  full_name='qm.grpc.qm_api.HighQmApiResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ok', full_name='qm.grpc.qm_api.HighQmApiResponse.ok', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='errors', full_name='qm.grpc.qm_api.HighQmApiResponse.errors', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2337,
  serialized_end=2424,
)


_QMCONFIG = _descriptor.Descriptor(
  name='QmConfig',
  full_name='qm.grpc.qm_api.QmConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='qm.grpc.qm_api.QmConfig.version', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='root', full_name='qm.grpc.qm_api.QmConfig.root', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2426,
  serialized_end=2492,
)


_MATRIX = _descriptor.Descriptor(
  name='Matrix',
  full_name='qm.grpc.qm_api.Matrix',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='v00', full_name='qm.grpc.qm_api.Matrix.v00', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v01', full_name='qm.grpc.qm_api.Matrix.v01', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v10', full_name='qm.grpc.qm_api.Matrix.v10', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='v11', full_name='qm.grpc.qm_api.Matrix.v11', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2494,
  serialized_end=2554,
)


_PORTREFERENCE = _descriptor.Descriptor(
  name='PortReference',
  full_name='qm.grpc.qm_api.PortReference',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controller', full_name='qm.grpc.qm_api.PortReference.controller', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number', full_name='qm.grpc.qm_api.PortReference.number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2556,
  serialized_end=2607,
)

_HIGHQMAPIREQUEST_SETCORRECTION.fields_by_name['correction'].message_type = _MATRIX
_HIGHQMAPIREQUEST_SETCORRECTION.fields_by_name['mixer'].message_type = _HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO
_HIGHQMAPIREQUEST_SETCORRECTION.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETCORRECTION.oneofs_by_name['oneof_set_correction'].fields.append(
  _HIGHQMAPIREQUEST_SETCORRECTION.fields_by_name['qe'])
_HIGHQMAPIREQUEST_SETCORRECTION.fields_by_name['qe'].containing_oneof = _HIGHQMAPIREQUEST_SETCORRECTION.oneofs_by_name['oneof_set_correction']
_HIGHQMAPIREQUEST_SETCORRECTION.oneofs_by_name['oneof_set_correction'].fields.append(
  _HIGHQMAPIREQUEST_SETCORRECTION.fields_by_name['mixer'])
_HIGHQMAPIREQUEST_SETCORRECTION.fields_by_name['mixer'].containing_oneof = _HIGHQMAPIREQUEST_SETCORRECTION.oneofs_by_name['oneof_set_correction']
_HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETFREQUENCY.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETFREQUENCY.oneofs_by_name['oneof_set_frequency'].fields.append(
  _HIGHQMAPIREQUEST_SETFREQUENCY.fields_by_name['qe'])
_HIGHQMAPIREQUEST_SETFREQUENCY.fields_by_name['qe'].containing_oneof = _HIGHQMAPIREQUEST_SETFREQUENCY.oneofs_by_name['oneof_set_frequency']
_HIGHQMAPIREQUEST_SETDCOFFSET.fields_by_name['qe'].message_type = _HIGHQMAPIREQUEST_QEPORT
_HIGHQMAPIREQUEST_SETDCOFFSET.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETDCOFFSET.oneofs_by_name['oneof_set_dc'].fields.append(
  _HIGHQMAPIREQUEST_SETDCOFFSET.fields_by_name['qe'])
_HIGHQMAPIREQUEST_SETDCOFFSET.fields_by_name['qe'].containing_oneof = _HIGHQMAPIREQUEST_SETDCOFFSET.oneofs_by_name['oneof_set_dc']
_HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET.fields_by_name['qe'].message_type = _HIGHQMAPIREQUEST_QEPORT
_HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET.oneofs_by_name['oneof_set_dc'].fields.append(
  _HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET.fields_by_name['qe'])
_HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET.fields_by_name['qe'].containing_oneof = _HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET.oneofs_by_name['oneof_set_dc']
_HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS.fields_by_name['filter'].message_type = _HIGHQMAPIREQUEST_ANALOGOUTPUTPORTFILTER
_HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS.fields_by_name['qe'].message_type = _HIGHQMAPIREQUEST_QEPORT
_HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS.oneofs_by_name['oneof_set_filter_Taps'].fields.append(
  _HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS.fields_by_name['qe'])
_HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS.fields_by_name['qe'].containing_oneof = _HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS.oneofs_by_name['oneof_set_filter_Taps']
_HIGHQMAPIREQUEST_ANALOGOUTPUTPORTFILTER.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETINPUTDCOFFSET.fields_by_name['qe'].message_type = _HIGHQMAPIREQUEST_QEPORT
_HIGHQMAPIREQUEST_SETINPUTDCOFFSET.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETINPUTDCOFFSET.oneofs_by_name['oneof_set_dc'].fields.append(
  _HIGHQMAPIREQUEST_SETINPUTDCOFFSET.fields_by_name['qe'])
_HIGHQMAPIREQUEST_SETINPUTDCOFFSET.fields_by_name['qe'].containing_oneof = _HIGHQMAPIREQUEST_SETINPUTDCOFFSET.oneofs_by_name['oneof_set_dc']
_HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['delay'].message_type = _HIGHQMAPIREQUEST_QEPORT
_HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['buffer'].message_type = _HIGHQMAPIREQUEST_QEPORT
_HIGHQMAPIREQUEST_SETDIGITALROUTE.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETDIGITALROUTE.oneofs_by_name['oneof_set_digital_route'].fields.append(
  _HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['delay'])
_HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['delay'].containing_oneof = _HIGHQMAPIREQUEST_SETDIGITALROUTE.oneofs_by_name['oneof_set_digital_route']
_HIGHQMAPIREQUEST_SETDIGITALROUTE.oneofs_by_name['oneof_set_digital_route'].fields.append(
  _HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['buffer'])
_HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['buffer'].containing_oneof = _HIGHQMAPIREQUEST_SETDIGITALROUTE.oneofs_by_name['oneof_set_digital_route']
_HIGHQMAPIREQUEST_SETDIGITALROUTE.oneofs_by_name['oneof_set_digital_route'].fields.append(
  _HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['tof'])
_HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['tof'].containing_oneof = _HIGHQMAPIREQUEST_SETDIGITALROUTE.oneofs_by_name['oneof_set_digital_route']
_HIGHQMAPIREQUEST_SETDIGITALROUTE.oneofs_by_name['oneof_set_digital_route'].fields.append(
  _HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['smearing'])
_HIGHQMAPIREQUEST_SETDIGITALROUTE.fields_by_name['smearing'].containing_oneof = _HIGHQMAPIREQUEST_SETDIGITALROUTE.oneofs_by_name['oneof_set_digital_route']
_HIGHQMAPIREQUEST_SETIOVALUES.fields_by_name['ioValueSetData'].message_type = _HIGHQMAPIREQUEST_IOVALUESETDATA
_HIGHQMAPIREQUEST_SETIOVALUES.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_SETIOVALUES.oneofs_by_name['oneof_setType'].fields.append(
  _HIGHQMAPIREQUEST_SETIOVALUES.fields_by_name['all'])
_HIGHQMAPIREQUEST_SETIOVALUES.fields_by_name['all'].containing_oneof = _HIGHQMAPIREQUEST_SETIOVALUES.oneofs_by_name['oneof_setType']
_HIGHQMAPIREQUEST_QEPORT.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_IOVALUESETDATA.containing_type = _HIGHQMAPIREQUEST
_HIGHQMAPIREQUEST_IOVALUESETDATA.oneofs_by_name['oneof_IO_type'].fields.append(
  _HIGHQMAPIREQUEST_IOVALUESETDATA.fields_by_name['intValue'])
_HIGHQMAPIREQUEST_IOVALUESETDATA.fields_by_name['intValue'].containing_oneof = _HIGHQMAPIREQUEST_IOVALUESETDATA.oneofs_by_name['oneof_IO_type']
_HIGHQMAPIREQUEST_IOVALUESETDATA.oneofs_by_name['oneof_IO_type'].fields.append(
  _HIGHQMAPIREQUEST_IOVALUESETDATA.fields_by_name['doubleValue'])
_HIGHQMAPIREQUEST_IOVALUESETDATA.fields_by_name['doubleValue'].containing_oneof = _HIGHQMAPIREQUEST_IOVALUESETDATA.oneofs_by_name['oneof_IO_type']
_HIGHQMAPIREQUEST_IOVALUESETDATA.oneofs_by_name['oneof_IO_type'].fields.append(
  _HIGHQMAPIREQUEST_IOVALUESETDATA.fields_by_name['booleanValue'])
_HIGHQMAPIREQUEST_IOVALUESETDATA.fields_by_name['booleanValue'].containing_oneof = _HIGHQMAPIREQUEST_IOVALUESETDATA.oneofs_by_name['oneof_IO_type']
_HIGHQMAPIREQUEST.fields_by_name['config'].message_type = _QMCONFIG
_HIGHQMAPIREQUEST.fields_by_name['strongConfig'].message_type = qm_dot_pb_dot_inc__qua__config__pb2._QUACONFIG
_HIGHQMAPIREQUEST.fields_by_name['setCorrection'].message_type = _HIGHQMAPIREQUEST_SETCORRECTION
_HIGHQMAPIREQUEST.fields_by_name['setFrequency'].message_type = _HIGHQMAPIREQUEST_SETFREQUENCY
_HIGHQMAPIREQUEST.fields_by_name['setDcOffset'].message_type = _HIGHQMAPIREQUEST_SETDCOFFSET
_HIGHQMAPIREQUEST.fields_by_name['setDigitalRoute'].message_type = _HIGHQMAPIREQUEST_SETDIGITALROUTE
_HIGHQMAPIREQUEST.fields_by_name['setIOValues'].message_type = _HIGHQMAPIREQUEST_SETIOVALUES
_HIGHQMAPIREQUEST.fields_by_name['setInputDcOffset'].message_type = _HIGHQMAPIREQUEST_SETINPUTDCOFFSET
_HIGHQMAPIREQUEST.fields_by_name['setOutputDcOffset'].message_type = _HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET
_HIGHQMAPIREQUEST.fields_by_name['setOutputFilterTaps'].message_type = _HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS
_HIGHQMAPIREQUEST.oneofs_by_name['api_oneof'].fields.append(
  _HIGHQMAPIREQUEST.fields_by_name['setCorrection'])
_HIGHQMAPIREQUEST.fields_by_name['setCorrection'].containing_oneof = _HIGHQMAPIREQUEST.oneofs_by_name['api_oneof']
_HIGHQMAPIREQUEST.oneofs_by_name['api_oneof'].fields.append(
  _HIGHQMAPIREQUEST.fields_by_name['setFrequency'])
_HIGHQMAPIREQUEST.fields_by_name['setFrequency'].containing_oneof = _HIGHQMAPIREQUEST.oneofs_by_name['api_oneof']
_HIGHQMAPIREQUEST.oneofs_by_name['api_oneof'].fields.append(
  _HIGHQMAPIREQUEST.fields_by_name['setDcOffset'])
_HIGHQMAPIREQUEST.fields_by_name['setDcOffset'].containing_oneof = _HIGHQMAPIREQUEST.oneofs_by_name['api_oneof']
_HIGHQMAPIREQUEST.oneofs_by_name['api_oneof'].fields.append(
  _HIGHQMAPIREQUEST.fields_by_name['setDigitalRoute'])
_HIGHQMAPIREQUEST.fields_by_name['setDigitalRoute'].containing_oneof = _HIGHQMAPIREQUEST.oneofs_by_name['api_oneof']
_HIGHQMAPIREQUEST.oneofs_by_name['api_oneof'].fields.append(
  _HIGHQMAPIREQUEST.fields_by_name['setIOValues'])
_HIGHQMAPIREQUEST.fields_by_name['setIOValues'].containing_oneof = _HIGHQMAPIREQUEST.oneofs_by_name['api_oneof']
_HIGHQMAPIREQUEST.oneofs_by_name['api_oneof'].fields.append(
  _HIGHQMAPIREQUEST.fields_by_name['setInputDcOffset'])
_HIGHQMAPIREQUEST.fields_by_name['setInputDcOffset'].containing_oneof = _HIGHQMAPIREQUEST.oneofs_by_name['api_oneof']
_HIGHQMAPIREQUEST.oneofs_by_name['api_oneof'].fields.append(
  _HIGHQMAPIREQUEST.fields_by_name['setOutputDcOffset'])
_HIGHQMAPIREQUEST.fields_by_name['setOutputDcOffset'].containing_oneof = _HIGHQMAPIREQUEST.oneofs_by_name['api_oneof']
_HIGHQMAPIREQUEST.oneofs_by_name['api_oneof'].fields.append(
  _HIGHQMAPIREQUEST.fields_by_name['setOutputFilterTaps'])
_HIGHQMAPIREQUEST.fields_by_name['setOutputFilterTaps'].containing_oneof = _HIGHQMAPIREQUEST.oneofs_by_name['api_oneof']
_HIGHQMAPIRESPONSE.fields_by_name['errors'].message_type = qm_dot_pb_dot_general__messages__pb2._ERRORMESSAGE
_QMCONFIG.fields_by_name['root'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
DESCRIPTOR.message_types_by_name['HighQmApiRequest'] = _HIGHQMAPIREQUEST
DESCRIPTOR.message_types_by_name['HighQmApiResponse'] = _HIGHQMAPIRESPONSE
DESCRIPTOR.message_types_by_name['QmConfig'] = _QMCONFIG
DESCRIPTOR.message_types_by_name['Matrix'] = _MATRIX
DESCRIPTOR.message_types_by_name['PortReference'] = _PORTREFERENCE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HighQmApiRequest = _reflection.GeneratedProtocolMessageType('HighQmApiRequest', (_message.Message,), {

  'SetCorrection' : _reflection.GeneratedProtocolMessageType('SetCorrection', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_SETCORRECTION,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.SetCorrection)
    })
  ,

  'SetCorrectionMixerInfo' : _reflection.GeneratedProtocolMessageType('SetCorrectionMixerInfo', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_SETCORRECTIONMIXERINFO,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.SetCorrectionMixerInfo)
    })
  ,

  'SetFrequency' : _reflection.GeneratedProtocolMessageType('SetFrequency', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_SETFREQUENCY,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.SetFrequency)
    })
  ,

  'SetDcOffset' : _reflection.GeneratedProtocolMessageType('SetDcOffset', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_SETDCOFFSET,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.SetDcOffset)
    })
  ,

  'SetOutputDcOffset' : _reflection.GeneratedProtocolMessageType('SetOutputDcOffset', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_SETOUTPUTDCOFFSET,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.SetOutputDcOffset)
    })
  ,

  'SetOutputFilterTaps' : _reflection.GeneratedProtocolMessageType('SetOutputFilterTaps', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_SETOUTPUTFILTERTAPS,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.SetOutputFilterTaps)
    })
  ,

  'AnalogOutputPortFilter' : _reflection.GeneratedProtocolMessageType('AnalogOutputPortFilter', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_ANALOGOUTPUTPORTFILTER,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.AnalogOutputPortFilter)
    })
  ,

  'SetInputDcOffset' : _reflection.GeneratedProtocolMessageType('SetInputDcOffset', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_SETINPUTDCOFFSET,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.SetInputDcOffset)
    })
  ,

  'SetDigitalRoute' : _reflection.GeneratedProtocolMessageType('SetDigitalRoute', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_SETDIGITALROUTE,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.SetDigitalRoute)
    })
  ,

  'SetIOValues' : _reflection.GeneratedProtocolMessageType('SetIOValues', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_SETIOVALUES,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.SetIOValues)
    })
  ,

  'QePort' : _reflection.GeneratedProtocolMessageType('QePort', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_QEPORT,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.QePort)
    })
  ,

  'IOValueSetData' : _reflection.GeneratedProtocolMessageType('IOValueSetData', (_message.Message,), {
    'DESCRIPTOR' : _HIGHQMAPIREQUEST_IOVALUESETDATA,
    '__module__' : 'qm.pb.inc_qm_api_pb2'
    # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest.IOValueSetData)
    })
  ,
  'DESCRIPTOR' : _HIGHQMAPIREQUEST,
  '__module__' : 'qm.pb.inc_qm_api_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiRequest)
  })
_sym_db.RegisterMessage(HighQmApiRequest)
_sym_db.RegisterMessage(HighQmApiRequest.SetCorrection)
_sym_db.RegisterMessage(HighQmApiRequest.SetCorrectionMixerInfo)
_sym_db.RegisterMessage(HighQmApiRequest.SetFrequency)
_sym_db.RegisterMessage(HighQmApiRequest.SetDcOffset)
_sym_db.RegisterMessage(HighQmApiRequest.SetOutputDcOffset)
_sym_db.RegisterMessage(HighQmApiRequest.SetOutputFilterTaps)
_sym_db.RegisterMessage(HighQmApiRequest.AnalogOutputPortFilter)
_sym_db.RegisterMessage(HighQmApiRequest.SetInputDcOffset)
_sym_db.RegisterMessage(HighQmApiRequest.SetDigitalRoute)
_sym_db.RegisterMessage(HighQmApiRequest.SetIOValues)
_sym_db.RegisterMessage(HighQmApiRequest.QePort)
_sym_db.RegisterMessage(HighQmApiRequest.IOValueSetData)

HighQmApiResponse = _reflection.GeneratedProtocolMessageType('HighQmApiResponse', (_message.Message,), {
  'DESCRIPTOR' : _HIGHQMAPIRESPONSE,
  '__module__' : 'qm.pb.inc_qm_api_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.HighQmApiResponse)
  })
_sym_db.RegisterMessage(HighQmApiResponse)

QmConfig = _reflection.GeneratedProtocolMessageType('QmConfig', (_message.Message,), {
  'DESCRIPTOR' : _QMCONFIG,
  '__module__' : 'qm.pb.inc_qm_api_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.QmConfig)
  })
_sym_db.RegisterMessage(QmConfig)

Matrix = _reflection.GeneratedProtocolMessageType('Matrix', (_message.Message,), {
  'DESCRIPTOR' : _MATRIX,
  '__module__' : 'qm.pb.inc_qm_api_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.Matrix)
  })
_sym_db.RegisterMessage(Matrix)

PortReference = _reflection.GeneratedProtocolMessageType('PortReference', (_message.Message,), {
  'DESCRIPTOR' : _PORTREFERENCE,
  '__module__' : 'qm.pb.inc_qm_api_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.qm_api.PortReference)
  })
_sym_db.RegisterMessage(PortReference)


_HIGHQMAPIREQUEST.fields_by_name['config']._options = None
_HIGHQMAPIREQUEST.fields_by_name['strongConfig']._options = None
_HIGHQMAPIREQUEST.fields_by_name['setDcOffset']._options = None
# @@protoc_insertion_point(module_scope)
